@@ -29,7 +29,6 @@ __copyright__ = "Copyright (c) 2004-2009 Sun Microsystems Inc." \
                 "Copyright (c) 2012 Igalia, S.L."
 __license__   = "LGPL"
 
-import gc
 import os
 import pyatspi
 import re
@@ -57,26 +56,24 @@ try:
 except:
     pass
 
-from .settings_manager import SettingsManager
-_settingsManager = SettingsManager()
-
-from .event_manager import EventManager
-_eventManager = EventManager()
-
-from .script_manager import ScriptManager
-_scriptManager = ScriptManager()
-
 from . import braille
 from . import debug
+from . import event_manager
 from . import notification_messages
 from . import orca_state
+from . import script_manager
 from . import settings
+from . import settings_manager
 from . import speech
 from .input_event import BrailleEvent
 from .input_event import KeyboardEvent
 from .orca_i18n import _
 from .orca_i18n import ngettext
 
+_eventManager = event_manager.getManager()
+_scriptManager = script_manager.getManager()
+_settingsManager = settings_manager.getManager()
+
 try:
     # If we don't have an active desktop, we will get a RuntimeError.
     from . import mouse_review
@@ -95,14 +92,6 @@ def onEnabledChanged(gsetting, key):
 def getSettingsManager():
     return _settingsManager
 
-if settings.debugMemoryUsage:
-    gc.set_debug(gc.DEBUG_UNCOLLECTABLE
-                 | gc.DEBUG_COLLECTABLE
-                 | gc.DEBUG_INSTANCES
-                 | gc.DEBUG_OBJECTS
-                 | gc.DEBUG_SAVEALL)
-
-
 EXIT_CODE_HANG = 50
 
 # The user-settings module (see loadUserSettings).
@@ -992,17 +981,6 @@ def examineProcesses():
         debug.println(
             debug.LEVEL_ALL, '%3i. %s (pid: %s) %s' % (i+1, name, pid, cmd))
 
-def cleanupGarbage():
-    """Cleans up garbage on the heap."""
-    gc.collect()
-    for obj in gc.garbage:
-        try:
-            if isinstance(obj, pyatspi.Accessibility.Accessible):
-                gc.garbage.remove(obj)
-                obj.__del__()
-        except:
-            pass
-
 def main():
     """The main entry point for Orca.  The exit codes for Orca will
     loosely be based on signals, where the exit code will be the
